/***************************************************************************
 $RCSfile$
 -------------------
 cvs         : $Id: account_l.h 933 2006-02-10 12:10:18Z cstim $
 begin       : Mon Mar 01 2004
 copyright   : (C) 2004 by Martin Preuss
 email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/


#ifndef AQBANKING_ACCOUNT_L_H
#define AQBANKING_ACCOUNT_L_H

#include <gwenhywfar/misc.h>
#include <gwenhywfar/list2.h>
#include <gwenhywfar/inherit.h>
#include <aqbanking/account_be.h>

AB_ACCOUNT *AB_Account_new(AB_BANKING *ab, AB_PROVIDER *pro);
void AB_Account_Attach(AB_ACCOUNT *acc);


int AB_Account_Update(AB_ACCOUNT *a);

void AB_Account_SetProvider(AB_ACCOUNT *a, AB_PROVIDER *pro);


AB_ACCOUNT *AB_Account_dup(AB_ACCOUNT *acc);
AB_ACCOUNT *AB_Account_fromDb(AB_BANKING *ab, GWEN_DB_NODE *db);
int AB_Account_toDb(const AB_ACCOUNT *a, GWEN_DB_NODE *db);


#endif /* AQBANKING_ACCOUNT_L_H */
